@@ -45,7 +45,9 @@ impl PageInfo {
 
     /// Set the page data, updating the history using the specified time and current data.
     pub fn set(&mut self, time: u64, data: Data) {
-        self.history.insert(time, self.current.take().unwrap());
+        if let Some(old) = self.current.take() {
+            self.history.insert(time, old);
+        }
         self.current = Some(data);
     }
 
